#ifndef UNW_REMOTE_ONLY
#define UNW_LOCAL_ONLY
#include "Gtest-dyn1.c"
#endif
